# IRx

**IRx** aims to provide a translator to LLVM-IR from
[**ASTx**](https://github.com/arxlang/astx) objects.

**ASTx** is a generic project that offers a way to compound in an expressive way
an **AST**. It is not specific for the **ArxLang** project, although it is main
focus is to provide all needed feature for it.

**IRx** uses **llvmlite** in order to generate **LLVM-IR** source.

- Software License: BSD 3 Clause
- Documentation: https://irx.arxlang.github.io.

## Features

- Generate **LLVM-IR** from **ASTx**.
